package org.expeditee.encryption.items;

import java.util.List;

import org.expeditee.settings.UserSettings;
import org.expeditee.settings.encryption.EncryptionDefaults;

public class EncryptionPermissionTriple {

	private UserAppliedEncryptionPermission ownerPermission;
	private UserAppliedEncryptionPermission groupPermission;
	private UserAppliedEncryptionPermission otherPermission;
	
	public EncryptionPermissionTriple(String permissionCode, 
			UserAppliedEncryptionPermission defaultPermission) {
		ownerPermission = defaultPermission;
		groupPermission = defaultPermission;
		otherPermission = defaultPermission;
		
		if (permissionCode != null) {
			permissionCode = permissionCode.trim().toLowerCase();
			if (permissionCode.length()  != 0) {
				// If the permission code has a character at index 0, then it is the owner permission.
				// If it does not then it will remain as the default permission passed to the function.
				String ownerPermissionCode = permissionCode.charAt(0) + "";
				this.ownerPermission = UserAppliedEncryptionPermission.getPermission(ownerPermissionCode, defaultPermission);
				
				// If the permission code has a character at index 1, then it is the group permission.
				// If it does not then it will remain as the default permission passed to the function.
				if (permissionCode.length() < 2) { return; }
				String groupPermissionCode = permissionCode.charAt(1) + "";
				this.groupPermission = UserAppliedEncryptionPermission.getPermission(groupPermissionCode, defaultPermission);
				
				if (permissionCode.length() < 3) { return; }
				String otherPermissionCode = permissionCode.charAt(2) + "";
				this.otherPermission = UserAppliedEncryptionPermission.getPermission(otherPermissionCode, defaultPermission);
			}
		}
	}
	
	public EncryptionPermissionTriple(
			UserAppliedEncryptionPermission ownerPermission,
			UserAppliedEncryptionPermission groupPermission,
			UserAppliedEncryptionPermission otherPermission) {
		this.ownerPermission = ownerPermission;
		this.groupPermission = groupPermission;
		this.otherPermission = otherPermission;
	}
	
	public EncryptionPermissionTriple(EncryptionPermissionTriple pt) {
		this.ownerPermission = pt.ownerPermission;
		this.groupPermission = pt.groupPermission;
		this.otherPermission = pt.otherPermission;
	}
	
	public UserAppliedEncryptionPermission getPermission(String ownerOfItem, List<String> group) {
		if (UserSettings.UserName.get().equals(ownerOfItem)) {
			return ownerPermission;
		} else if (group.contains(UserSettings.UserName.get())) {
			return groupPermission;
		} else {
			return otherPermission;
		}
	}
	
	public static EncryptionPermissionTriple convertString(String permissionCode) {
		UserAppliedEncryptionPermission defaultPermission = UserAppliedEncryptionPermission.values()[EncryptionDefaults.DefaultEncryptionPermission.get()];
		return new EncryptionPermissionTriple(permissionCode, defaultPermission);
	}
	
	public String getCode() {
		return Integer.toString(ownerPermission.getCode()) + Integer.toString(groupPermission.getCode()) + Integer.toString(otherPermission.getCode());
	}
	
	@Override
	public String toString() {
		return ownerPermission.toString() + ":" + groupPermission.toString() + ":" + otherPermission.toString();
	}
}
